@@ -1,5 +1,5 @@
 /*
- *  $Id: fselect.c,v 1.116 2021/03/05 00:47:39 tom Exp $
+ *  $Id: fselect.c,v 1.117 2021/06/21 19:50:35 tom Exp $
  *
  *  fselect.c -- implements the file-selector box
  *
@@ -652,6 +652,8 @@ dlg_fselect(const char *title, const char *path, int height, int width, int dsel
 #ifdef KEY_RESIZE
   retry:
 #endif
+    if (height > 0)
+	height += MIN_HIGH;
     dlg_auto_size(title, "", &height, &width, MIN_HIGH + min_items, min_wide);
 
     dlg_print_size(height, width);
